# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: delta_enclave_api.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'delta_enclave_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64\x65lta_enclave_api.proto\x12\x11\x64\x65lta_enclave_api\"\xcf\x01\n\x07Request\x12:\n\x0c\x64\x65ltaRequest\x18\x01 \x01(\x0b\x32\".delta_enclave_api.DataNoncePubkeyH\x00\x12?\n\x10\x65xtensionMessage\x18\x02 \x01(\x0b\x32#.delta_enclave_api.ExtensionMessageH\x00\x12<\n\x0e\x64\x65ltaRequestV2\x18\x03 \x01(\x0b\x32\".delta_enclave_api.DataNoncePubkeyH\x00\x42\t\n\x07request\"1\n\x10\x45xtensionMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"T\n\x08Response\x12\x1c\n\x12successfulResponse\x18\x01 \x01(\x0cH\x00\x12\x1e\n\x14unsuccessfulResponse\x18\x02 \x01(\tH\x00\x42\n\n\x08response\">\n\x0f\x44\x61taNoncePubkey\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\x12\x0e\n\x06pubkey\x18\x03 \x01(\x0c\"(\n\tDataNonce\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\"j\n\x16SealedEncryptedMessage\x12\x36\n\x10\x65ncryptedMessage\x18\x01 \x01(\x0b\x32\x1c.delta_enclave_api.DataNonce\x12\x18\n\x10sealingKeyParams\x18\x02 \x01(\x0c\"W\n\x10\x45ncryptionHeader\x12/\n\x08\x63hilyKey\x18\x01 \x01(\x0b\x32\x1b.delta_enclave_api.ChilyKeyH\x00\x42\x12\n\x10\x65ncryptionHeader\"#\n\x08\x43hilyKey\x12\x17\n\x0f\x65ncryptionNonce\x18\x02 \x01(\x0c\" \n\rVersionHeader\x12\x0f\n\x07version\x18\x01 \x01(\x03\"\x83\x01\n\x0b\x43hunkHeader\x12\x14\n\x0c\x65xtraEntropy\x18\x01 \x01(\x0c\x12!\n\x14untrustedContentSize\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\"\n\x1auntrustedChunkContentSizes\x18\x03 \x03(\x04\x42\x17\n\x15_untrustedContentSizeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'delta_enclave_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUEST']._serialized_start=47
  _globals['_REQUEST']._serialized_end=254
  _globals['_EXTENSIONMESSAGE']._serialized_start=256
  _globals['_EXTENSIONMESSAGE']._serialized_end=305
  _globals['_RESPONSE']._serialized_start=307
  _globals['_RESPONSE']._serialized_end=391
  _globals['_DATANONCEPUBKEY']._serialized_start=393
  _globals['_DATANONCEPUBKEY']._serialized_end=455
  _globals['_DATANONCE']._serialized_start=457
  _globals['_DATANONCE']._serialized_end=497
  _globals['_SEALEDENCRYPTEDMESSAGE']._serialized_start=499
  _globals['_SEALEDENCRYPTEDMESSAGE']._serialized_end=605
  _globals['_ENCRYPTIONHEADER']._serialized_start=607
  _globals['_ENCRYPTIONHEADER']._serialized_end=694
  _globals['_CHILYKEY']._serialized_start=696
  _globals['_CHILYKEY']._serialized_end=731
  _globals['_VERSIONHEADER']._serialized_start=733
  _globals['_VERSIONHEADER']._serialized_end=765
  _globals['_CHUNKHEADER']._serialized_start=768
  _globals['_CHUNKHEADER']._serialized_end=899
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: compute_s3_sink.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'compute_s3_sink.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ompute_s3_sink.proto\x12\x0f\x63ompute_s3_sink\"\xdd\x02\n\x19S3SinkWorkerConfiguration\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12*\n\x07objects\x18\x04 \x03(\x0b\x32\x19.compute_s3_sink.S3Object\x12/\n\ns3Provider\x18\x05 \x01(\x0e\x32\x1b.compute_s3_sink.S3Provider\x12I\n\x16userDefinedCredentials\x18\x06 \x01(\x0b\x32\'.compute_s3_sink.UserDefinedCredentialsH\x00\x12=\n\x10\x64qDspCredentials\x18\x07 \x01(\x0b\x32!.compute_s3_sink.DqDspCredentialsH\x00\x12\x18\n\x0b\x63ontentType\x18\x08 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b\x63redentialsB\x0e\n\x0c_contentType\"8\n\x16UserDefinedCredentials\x12\x1e\n\x16userDefinedCredentials\x18\x01 \x01(\t\"H\n\x10\x44qDspCredentials\x12\x34\n\x07\x64spType\x18\x01 \x01(\x0e\x32#.compute_s3_sink.DspCredentialsType\"~\n\x08S3Object\x12\x12\n\ndependency\x18\x01 \x01(\t\x12)\n\x03zip\x18\x02 \x01(\x0b\x32\x1a.compute_s3_sink.ZipObjectH\x00\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.compute_s3_sink.RawObjectH\x00\x42\x08\n\x06\x66ormat\"\x18\n\tRawObject\x12\x0b\n\x03key\x18\x01 \x01(\t\"{\n\tZipObject\x12\x31\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1b.compute_s3_sink.SingleFileH\x00\x12\x33\n\x0b\x66ullContent\x18\x02 \x01(\x0b\x32\x1c.compute_s3_sink.FullContentH\x00\x42\x06\n\x04kind\"\'\n\nSingleFile\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\r\n\x0b\x46ullContent\"5\n\rS3Credentials\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t*\x1e\n\nS3Provider\x12\x07\n\x03\x41WS\x10\x00\x12\x07\n\x03GCS\x10\x01*-\n\x12\x44spCredentialsType\x12\x0b\n\x07SPLICKY\x10\x00\x12\n\n\x06ONELOG\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'compute_s3_sink_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_S3PROVIDER']._serialized_start=916
  _globals['_S3PROVIDER']._serialized_end=946
  _globals['_DSPCREDENTIALSTYPE']._serialized_start=948
  _globals['_DSPCREDENTIALSTYPE']._serialized_end=993
  _globals['_S3SINKWORKERCONFIGURATION']._serialized_start=43
  _globals['_S3SINKWORKERCONFIGURATION']._serialized_end=392
  _globals['_USERDEFINEDCREDENTIALS']._serialized_start=394
  _globals['_USERDEFINEDCREDENTIALS']._serialized_end=450
  _globals['_DQDSPCREDENTIALS']._serialized_start=452
  _globals['_DQDSPCREDENTIALS']._serialized_end=524
  _globals['_S3OBJECT']._serialized_start=526
  _globals['_S3OBJECT']._serialized_end=652
  _globals['_RAWOBJECT']._serialized_start=654
  _globals['_RAWOBJECT']._serialized_end=678
  _globals['_ZIPOBJECT']._serialized_start=680
  _globals['_ZIPOBJECT']._serialized_end=803
  _globals['_SINGLEFILE']._serialized_start=805
  _globals['_SINGLEFILE']._serialized_end=844
  _globals['_FULLCONTENT']._serialized_start=846
  _globals['_FULLCONTENT']._serialized_end=859
  _globals['_S3CREDENTIALS']._serialized_start=861
  _globals['_S3CREDENTIALS']._serialized_end=914
# @@protoc_insertion_point(module_scope)



from .compute_sql_pb2 import (
    ColumnType,
    ComputationConfiguration,
    Constraint,
    NamedColumn,
    PrimitiveType,
    PrivacySettings,
    SqlWorkerConfiguration,
    TableDependencyMapping,
    TableSchema,
    ValidationConfiguration,
)
